import { Component, Directive, ElementRef, Injectable, Input, NgModule, Renderer2 } from '@angular/core';
import { Subject as Subject$1 } from 'rxjs/Subject';
var EsBeaconService = (function () {
    function EsBeaconService() {
        this.width = "10px";
        this.size = "12px";
        this.top = "-12px";
        this.bottom = "";
        this.left = "-12px";
        this.right = "";
        this.color = "hsl(235, 70%, 50%)";
        this.frequency = "2000ms";
        this.synchronisation = false;
        this.change = new Subject$1();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    EsBeaconService.prototype.setDefaultWidth = function (value) {
        this.width = String(value);
        this.change.next();
    };
    /**
     * @param {?} value
     * @return {?}
     */
    EsBeaconService.prototype.setDefaultSize = function (value) {
        this.size = String(value);
        this.change.next();
    };
    /**
     * @param {?} value
     * @return {?}
     */
    EsBeaconService.prototype.setDefaultTop = function (value) {
        this.top = String(value);
        this.bottom = "";
        this.change.next();
    };
    /**
     * @param {?} value
     * @return {?}
     */
    EsBeaconService.prototype.setDefaultBottom = function (value) {
        this.top = "";
        this.bottom = String(value);
        this.change.next();
    };
    /**
     * @param {?} value
     * @return {?}
     */
    EsBeaconService.prototype.setDefaultLeft = function (value) {
        this.left = String(value);
        this.right = "";
        this.change.next();
    };
    /**
     * @param {?} value
     * @return {?}
     */
    EsBeaconService.prototype.setDefaultRight = function (value) {
        this.left = "";
        this.right = String(value);
        this.change.next();
    };
    /**
     * @param {?} value
     * @return {?}
     */
    EsBeaconService.prototype.setDefaultFrequency = function (value) {
        this.frequency = String(value);
        this.change.next();
    };
    /**
     * @param {?} value
     * @return {?}
     */
    EsBeaconService.prototype.setDefaultColor = function (value) {
        this.color = String(value);
        this.change.next();
    };
    /**
     * @param {?} value
     * @return {?}
     */
    EsBeaconService.prototype.setDefaultSynchronisation = function (value) {
        this.synchronisation = value;
        this.change.next();
    };
    return EsBeaconService;
}());
EsBeaconService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
EsBeaconService.ctorParameters = function () { return []; };
var BeaconComponent = (function () {
    /**
     * @param {?} beacon
     */
    function BeaconComponent(beacon) {
        this.beacon = beacon;
    }
    /**
     * @return {?}
     */
    BeaconComponent.prototype.ngOnInit = function () {
        var _this = this;
        if (this.synchronisation)
            this._synchronisation = parseInt(/** @type {?} */ (this.synchronisation), 10) * 113 + "ms";
        else if (!this.beacon.synchronisation)
            this._synchronisation = Math.floor(Math.random() * 1000) + "ms";
        else
            this._synchronisation = "";
        this.update();
        this.subscription = this.beacon.change.subscribe(function () { return _this.update(); });
    };
    /**
     * @return {?}
     */
    BeaconComponent.prototype.ngOnDestroy = function () {
        this.subscription.unsubscribe();
    };
    /**
     * @return {?}
     */
    BeaconComponent.prototype.ngOnChanges = function () {
        this.update();
    };
    /**
     * @return {?}
     */
    BeaconComponent.prototype.update = function () {
        this._size = this.size || this.beacon.size;
        this._width = this.width || this.beacon.width;
        this._color = this.color || this.beacon.color;
        this._frequency = this.frequency || this.beacon.frequency;
        if (this.top) {
            this._top = this.top;
            this._bottom = "";
        }
        else if (this.bottom) {
            this._top = "";
            this._bottom = this.bottom;
        }
        else {
            this._top = this.beacon.top;
            this._bottom = this.beacon.bottom;
        }
        if (this.left) {
            this._left = this.left;
            this._right = "";
        }
        else if (this.right) {
            this._left = "";
            this._right = this.right;
        }
        else {
            this._left = this.beacon.left;
            this._right = this.beacon.right;
        }
    };
    return BeaconComponent;
}());
BeaconComponent.decorators = [
    { type: Component, args: [{
                selector: "es-beacon",
                template: "\n      <span class=\"es-beacon\"\n            [style.fontSize]=\"_size\"\n            [style.width]=\"_width\" [style.height]=\"_width\"\n            [style.animationDuration]=\"_frequency\"\n            [style.animationDelay]=\"_synchronisation\"\n            [style.color]=\"_color\"\n            [style.backgroundColor]=\"_color\"\n            [style.top]=\"_top\"\n            [style.bottom]=\"_bottom\"\n            [style.left]=\"_left\"\n            [style.right]=\"_right\"\n      ></span>\n   ",
                styles: ["\n     .es-beacon {\n        position: absolute;\n\n        border-radius: 50%;\n\n        -webkit-animation-name: beacon;\n\n                animation-name: beacon;\n        -webkit-animation-timing-function: ease-out;\n                animation-timing-function: ease-out;\n        -webkit-animation-iteration-count: infinite;\n                animation-iteration-count: infinite;\n\n     }\n\n     @-webkit-keyframes beacon {\n        0%, 60% {\n           -webkit-box-shadow: 0 0 0 0;\n                   box-shadow: 0 0 0 0;\n        }\n        100% {\n           -webkit-box-shadow: 0 0 3em 1em;\n                   box-shadow: 0 0 3em 1em;\n        }\n     }\n\n     @keyframes beacon {\n        0%, 60% {\n           -webkit-box-shadow: 0 0 0 0;\n                   box-shadow: 0 0 0 0;\n        }\n        100% {\n           -webkit-box-shadow: 0 0 3em 1em;\n                   box-shadow: 0 0 3em 1em;\n        }\n     }\n   "]
            },] },
];
/**
 * @nocollapse
 */
BeaconComponent.ctorParameters = function () { return [
    { type: EsBeaconService, },
]; };
BeaconComponent.propDecorators = {
    'size': [{ type: Input },],
    'width': [{ type: Input },],
    'frequency': [{ type: Input },],
    'color': [{ type: Input },],
    'synchronisation': [{ type: Input },],
    'top': [{ type: Input },],
    'bottom': [{ type: Input },],
    'left': [{ type: Input },],
    'right': [{ type: Input },],
};
var BeaconContainerDirective = (function () {
    /**
     * @param {?} element
     * @param {?} renderer
     */
    function BeaconContainerDirective(element, renderer) {
        this.element = element;
        this.renderer = renderer;
        renderer.addClass(element.nativeElement, "es-beacon-container");
    }
    Object.defineProperty(BeaconContainerDirective.prototype, "esBeaconContainer", {
        /**
         * @param {?} value
         * @return {?}
         */
        set: function (value) {
            switch (value) {
                case "relative":
                case "absolute":
                case "fixed":
                    this.applyAttribute(value);
                    break;
                case "static":
                case false:
                case null:
                    this.applyAttribute("static");
                    break;
                default:
                    this.applyAttribute("relative");
                    break;
            }
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @param {?} position
     * @return {?}
     */
    BeaconContainerDirective.prototype.applyAttribute = function (position) {
        this.renderer.setStyle(this.element.nativeElement, "position", position);
    };
    return BeaconContainerDirective;
}());
BeaconContainerDirective.decorators = [
    { type: Directive, args: [{
                selector: "[esBeaconContainer]"
            },] },
];
/**
 * @nocollapse
 */
BeaconContainerDirective.ctorParameters = function () { return [
    { type: ElementRef, },
    { type: Renderer2, },
]; };
BeaconContainerDirective.propDecorators = {
    'esBeaconContainer': [{ type: Input },],
};
var EsBeaconModule = (function () {
    function EsBeaconModule() {
    }
    return EsBeaconModule;
}());
EsBeaconModule.decorators = [
    { type: NgModule, args: [{
                imports: [],
                declarations: [
                    BeaconComponent,
                    BeaconContainerDirective
                ],
                providers: [
                    EsBeaconService
                ],
                exports: [
                    BeaconComponent,
                    BeaconContainerDirective
                ]
            },] },
];
/**
 * @nocollapse
 */
EsBeaconModule.ctorParameters = function () { return []; };
/**
 * Generated bundle index. Do not edit.
 */
export { EsBeaconModule, EsBeaconService, BeaconContainerDirective as ɵb, BeaconComponent as ɵa };
//# sourceMappingURL=esbeacon.es5.js.map
