import { Component, Directive, ElementRef, Injectable, Input, NgModule, Renderer2 } from '@angular/core';
import { Subject as Subject$1 } from 'rxjs/Subject';

class EsBeaconService {
    constructor() {
        this.width = "10px";
        this.size = "12px";
        this.top = "-12px";
        this.bottom = "";
        this.left = "-12px";
        this.right = "";
        this.color = "hsl(235, 70%, 50%)";
        this.frequency = "2000ms";
        this.synchronisation = false;
        this.change = new Subject$1();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    setDefaultWidth(value) {
        this.width = String(value);
        this.change.next();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    setDefaultSize(value) {
        this.size = String(value);
        this.change.next();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    setDefaultTop(value) {
        this.top = String(value);
        this.bottom = "";
        this.change.next();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    setDefaultBottom(value) {
        this.top = "";
        this.bottom = String(value);
        this.change.next();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    setDefaultLeft(value) {
        this.left = String(value);
        this.right = "";
        this.change.next();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    setDefaultRight(value) {
        this.left = "";
        this.right = String(value);
        this.change.next();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    setDefaultFrequency(value) {
        this.frequency = String(value);
        this.change.next();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    setDefaultColor(value) {
        this.color = String(value);
        this.change.next();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    setDefaultSynchronisation(value) {
        this.synchronisation = value;
        this.change.next();
    }
}
EsBeaconService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
EsBeaconService.ctorParameters = () => [];

class BeaconComponent {
    /**
     * @param {?} beacon
     */
    constructor(beacon) {
        this.beacon = beacon;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.synchronisation)
            this._synchronisation = parseInt(/** @type {?} */ (this.synchronisation), 10) * 113 + "ms";
        else if (!this.beacon.synchronisation)
            this._synchronisation = Math.floor(Math.random() * 1000) + "ms";
        else
            this._synchronisation = "";
        this.update();
        this.subscription = this.beacon.change.subscribe(() => this.update());
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.subscription.unsubscribe();
    }
    /**
     * @return {?}
     */
    ngOnChanges() {
        this.update();
    }
    /**
     * @return {?}
     */
    update() {
        this._size = this.size || this.beacon.size;
        this._width = this.width || this.beacon.width;
        this._color = this.color || this.beacon.color;
        this._frequency = this.frequency || this.beacon.frequency;
        if (this.top) {
            this._top = this.top;
            this._bottom = "";
        }
        else if (this.bottom) {
            this._top = "";
            this._bottom = this.bottom;
        }
        else {
            this._top = this.beacon.top;
            this._bottom = this.beacon.bottom;
        }
        if (this.left) {
            this._left = this.left;
            this._right = "";
        }
        else if (this.right) {
            this._left = "";
            this._right = this.right;
        }
        else {
            this._left = this.beacon.left;
            this._right = this.beacon.right;
        }
    }
}
BeaconComponent.decorators = [
    { type: Component, args: [{
                selector: "es-beacon",
                template: `
      <span class="es-beacon"
            [style.fontSize]="_size"
            [style.width]="_width" [style.height]="_width"
            [style.animationDuration]="_frequency"
            [style.animationDelay]="_synchronisation"
            [style.color]="_color"
            [style.backgroundColor]="_color"
            [style.top]="_top"
            [style.bottom]="_bottom"
            [style.left]="_left"
            [style.right]="_right"
      ></span>
   `,
                styles: [`
     .es-beacon {
        position: absolute;

        border-radius: 50%;

        -webkit-animation-name: beacon;

                animation-name: beacon;
        -webkit-animation-timing-function: ease-out;
                animation-timing-function: ease-out;
        -webkit-animation-iteration-count: infinite;
                animation-iteration-count: infinite;

     }

     @-webkit-keyframes beacon {
        0%, 60% {
           -webkit-box-shadow: 0 0 0 0;
                   box-shadow: 0 0 0 0;
        }
        100% {
           -webkit-box-shadow: 0 0 3em 1em;
                   box-shadow: 0 0 3em 1em;
        }
     }

     @keyframes beacon {
        0%, 60% {
           -webkit-box-shadow: 0 0 0 0;
                   box-shadow: 0 0 0 0;
        }
        100% {
           -webkit-box-shadow: 0 0 3em 1em;
                   box-shadow: 0 0 3em 1em;
        }
     }
   `]
            },] },
];
/**
 * @nocollapse
 */
BeaconComponent.ctorParameters = () => [
    { type: EsBeaconService, },
];
BeaconComponent.propDecorators = {
    'size': [{ type: Input },],
    'width': [{ type: Input },],
    'frequency': [{ type: Input },],
    'color': [{ type: Input },],
    'synchronisation': [{ type: Input },],
    'top': [{ type: Input },],
    'bottom': [{ type: Input },],
    'left': [{ type: Input },],
    'right': [{ type: Input },],
};

class BeaconContainerDirective {
    /**
     * @param {?} element
     * @param {?} renderer
     */
    constructor(element, renderer) {
        this.element = element;
        this.renderer = renderer;
        renderer.addClass(element.nativeElement, "es-beacon-container");
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set esBeaconContainer(value) {
        switch (value) {
            case "relative":
            case "absolute":
            case "fixed":
                this.applyAttribute(value);
                break;
            case "static":
            case false:
            case null:
                this.applyAttribute("static");
                break;
            default:
                this.applyAttribute("relative");
                break;
        }
    }
    /**
     * @param {?} position
     * @return {?}
     */
    applyAttribute(position) {
        this.renderer.setStyle(this.element.nativeElement, "position", position);
    }
}
BeaconContainerDirective.decorators = [
    { type: Directive, args: [{
                selector: "[esBeaconContainer]"
            },] },
];
/**
 * @nocollapse
 */
BeaconContainerDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: Renderer2, },
];
BeaconContainerDirective.propDecorators = {
    'esBeaconContainer': [{ type: Input },],
};

class EsBeaconModule {
}
EsBeaconModule.decorators = [
    { type: NgModule, args: [{
                imports: [],
                declarations: [
                    BeaconComponent,
                    BeaconContainerDirective
                ],
                providers: [
                    EsBeaconService
                ],
                exports: [
                    BeaconComponent,
                    BeaconContainerDirective
                ]
            },] },
];
/**
 * @nocollapse
 */
EsBeaconModule.ctorParameters = () => [];

/**
 * Generated bundle index. Do not edit.
 */

export { EsBeaconModule, EsBeaconService, BeaconContainerDirective as ɵb, BeaconComponent as ɵa };
//# sourceMappingURL=esbeacon.js.map
